@@ -2,11 +2,12 @@
 
 open! Import
 
-type 'a t = 'a array [@@deriving_inline compare, globalize, sexp, sexp_grammar]
+type 'a t = 'a array [@@deriving_inline compare ~localize, globalize, sexp, sexp_grammar]
 
 include Ppx_compare_lib.Comparable.S1 with type 'a t := 'a t
+include Ppx_compare_lib.Comparable.S_local1 with type 'a t := 'a t
 
-val globalize : (('a[@ocaml.local]) -> 'a) -> ('a t[@ocaml.local]) -> 'a t
+val globalize : ('a -> 'a) -> 'a t -> 'a t
 
 include Sexplib0.Sexpable.S1 with type 'a t := 'a t
 
@@ -63,7 +64,7 @@ val create : len:int -> 'a -> 'a t
 
 (** [create_local ~len x] is like [create]. It allocates the array on the local stack. The
     array's elements are still global. *)
-val create_local : len:int -> 'a -> ('a t[@local])
+val create_local : len:int -> 'a -> 'a t
 
 (** [create_float_uninitialized ~len] creates a float array of length [len] with
     uninitialized elements -- that is, they may contain arbitrary, nondeterministic float
@@ -115,28 +116,19 @@ include Blit.S1 with type 'a t := 'a t
 
 (** [folding_map] is a version of [map] that threads an accumulator through calls to
     [f]. *)
-val folding_map : 'a t -> init:'acc -> f:(('acc -> 'a -> 'acc * 'b)[@local]) -> 'b t
+val folding_map : 'a t -> init:'acc -> f:('acc -> 'a -> 'acc * 'b) -> 'b t
 
-val folding_mapi
-  :  'a t
-  -> init:'acc
-  -> f:((int -> 'acc -> 'a -> 'acc * 'b)[@local])
-  -> 'b t
+val folding_mapi : 'a t -> init:'acc -> f:(int -> 'acc -> 'a -> 'acc * 'b) -> 'b t
 
 (** [Array.fold_map] is a combination of [Array.fold] and [Array.map] that threads an
     accumulator through calls to [f]. *)
-val fold_map : 'a t -> init:'acc -> f:(('acc -> 'a -> 'acc * 'b)[@local]) -> 'acc * 'b t
+val fold_map : 'a t -> init:'acc -> f:('acc -> 'a -> 'acc * 'b) -> 'acc * 'b t
 
-val fold_mapi
-  :  'a t
-  -> init:'acc
-  -> f:((int -> 'acc -> 'a -> 'acc * 'b)[@local])
-  -> 'acc * 'b t
+val fold_mapi : 'a t -> init:'acc -> f:(int -> 'acc -> 'a -> 'acc * 'b) -> 'acc * 'b t
 
 (** [Array.fold_right f a ~init] computes [f a.(0) (f a.(1) ( ... (f a.(n-1) init) ...))],
     where [n] is the length of the array [a]. *)
-val fold_right : 'a t -> f:(('a -> 'acc -> 'acc)[@local]) -> init:'acc -> 'acc
-
+val fold_right : 'a t -> f:('a -> 'acc -> 'acc) -> init:'acc -> 'acc
 
 (** All sort functions in this module sort in increasing order by default.  *)
 
@@ -144,22 +136,22 @@ val fold_right : 'a t -> f:(('a -> 'acc -> 'acc)[@local]) -> init:'acc -> 'acc
 
     To sort only part of the array, specify [pos] to be the index to start sorting from
     and [len] indicating how many elements to sort. *)
-val sort : ?pos:int -> ?len:int -> 'a t -> compare:(('a -> 'a -> int)[@local]) -> unit
+val sort : ?pos:int -> ?len:int -> 'a t -> compare:('a -> 'a -> int) -> unit
 
 val stable_sort : 'a t -> compare:('a -> 'a -> int) -> unit
-val is_sorted : 'a t -> compare:(('a -> 'a -> int)[@local]) -> bool
+val is_sorted : 'a t -> compare:('a -> 'a -> int) -> bool
 
 (** [is_sorted_strictly xs ~compare] iff [is_sorted xs ~compare] and no two
     consecutive elements in [xs] are equal according to [compare]. *)
-val is_sorted_strictly : 'a t -> compare:(('a -> 'a -> int)[@local]) -> bool
+val is_sorted_strictly : 'a t -> compare:('a -> 'a -> int) -> bool
 
 (** Merges two arrays: assuming that [a1] and [a2] are sorted according to the comparison
     function [compare], [merge a1 a2 ~compare] will return a sorted array containing all
     the elements of [a1] and [a2]. If several elements compare equal, the elements of [a1]
     will be before the elements of [a2]. *)
-val merge : 'a t -> 'a t -> compare:(('a -> 'a -> int)[@local]) -> 'a t
+val merge : 'a t -> 'a t -> compare:('a -> 'a -> int) -> 'a t
 
-val partitioni_tf : 'a t -> f:((int -> 'a -> bool)[@local]) -> 'a t * 'a t
+val partitioni_tf : 'a t -> f:(int -> 'a -> bool) -> 'a t * 'a t
 val cartesian_product : 'a t -> 'b t -> ('a * 'b) t
 
 (** [transpose] in the sense of a matrix transpose.  It returns [None] if the arrays are
@@ -176,21 +168,15 @@ val filter_opt : 'a option t -> 'a t
 (** Functions with the 2 suffix raise an exception if the lengths of the two given arrays
     aren't the same. *)
 
-val iter2_exn : 'a t -> 'b t -> f:(('a -> 'b -> unit)[@local]) -> unit
-val map2_exn : 'a t -> 'b t -> f:(('a -> 'b -> 'c)[@local]) -> 'c t
-
-val fold2_exn
-  :  'a t
-  -> 'b t
-  -> init:'acc
-  -> f:(('acc -> 'a -> 'b -> 'acc)[@local])
-  -> 'acc
+val iter2_exn : 'a t -> 'b t -> f:('a -> 'b -> unit) -> unit
+val map2_exn : 'a t -> 'b t -> f:('a -> 'b -> 'c) -> 'c t
+val fold2_exn : 'a t -> 'b t -> init:'acc -> f:('acc -> 'a -> 'b -> 'acc) -> 'acc
 
 (** [for_all2_exn t1 t2 ~f] fails if [length t1 <> length t2]. *)
-val for_all2_exn : 'a t -> 'b t -> f:(('a -> 'b -> bool)[@local]) -> bool
+val for_all2_exn : 'a t -> 'b t -> f:('a -> 'b -> bool) -> bool
 
 (** [exists2_exn t1 t2 ~f] fails if [length t1 <> length t2]. *)
-val exists2_exn : 'a t -> 'b t -> f:(('a -> 'b -> bool)[@local]) -> bool
+val exists2_exn : 'a t -> 'b t -> f:('a -> 'b -> bool) -> bool
 
 (** [swap arr i j] swaps the value at index [i] with that at index [j]. *)
 val swap : 'a t -> int -> int -> unit
@@ -205,49 +191,45 @@ val rev : 'a t -> 'a t
 val of_list_rev : 'a list -> 'a t
 
 (** [of_list_map l ~f] is the same as [of_list (List.map l ~f)]. *)
-val of_list_map : 'a list -> f:(('a -> 'b)[@local]) -> 'b t
+val of_list_map : 'a list -> f:('a -> 'b) -> 'b t
 
 (** [of_list_mapi l ~f] is the same as [of_list (List.mapi l ~f)]. *)
-val of_list_mapi : 'a list -> f:((int -> 'a -> 'b)[@local]) -> 'b t
+val of_list_mapi : 'a list -> f:(int -> 'a -> 'b) -> 'b t
 
 (** [of_list_rev_map l ~f] is the same as [of_list (List.rev_map l ~f)]. *)
-val of_list_rev_map : 'a list -> f:(('a -> 'b)[@local]) -> 'b t
+val of_list_rev_map : 'a list -> f:('a -> 'b) -> 'b t
 
 (** [of_list_rev_mapi l ~f] is the same as [of_list (List.rev_mapi l ~f)]. *)
-val of_list_rev_mapi : 'a list -> f:((int -> 'a -> 'b)[@local]) -> 'b t
+val of_list_rev_mapi : 'a list -> f:(int -> 'a -> 'b) -> 'b t
 
 (** Modifies an array in place, applying [f] to every element of the array *)
-val map_inplace : 'a t -> f:(('a -> 'a)[@local]) -> unit
-
+val map_inplace : 'a t -> f:('a -> 'a) -> unit
 
 (** [find_exn f t] returns the first [a] in [t] for which [f t.(i)] is true.  It raises
     [Stdlib.Not_found] or [Not_found_s] if there is no such [a]. *)
-val find_exn : 'a t -> f:(('a -> bool)[@local]) -> 'a
+val find_exn : 'a t -> f:('a -> bool) -> 'a
 
 (** Returns the first evaluation of [f] that returns [Some].  Raises [Stdlib.Not_found] or
     [Not_found_s] if [f] always returns [None].  *)
-val find_map_exn : 'a t -> f:(('a -> 'b option)[@local]) -> 'b
+val find_map_exn : 'a t -> f:('a -> 'b option) -> 'b
 
 (** [findi_exn t f] returns the first index [i] of [t] for which [f i t.(i)] is true.  It
     raises [Stdlib.Not_found] or [Not_found_s] if there is no such element. *)
-val findi_exn : 'a t -> f:((int -> 'a -> bool)[@local]) -> int * 'a
+val findi_exn : 'a t -> f:(int -> 'a -> bool) -> int * 'a
 
 (** [find_mapi_exn] is like [find_map_exn] but passes the index as an argument. *)
-val find_mapi_exn : 'a t -> f:((int -> 'a -> 'b option)[@local]) -> 'b
+val find_mapi_exn : 'a t -> f:(int -> 'a -> 'b option) -> 'b
 
 (** [find_consecutive_duplicate t ~equal] returns the first pair of consecutive elements
     [(a1, a2)] in [t] such that [equal a1 a2].  They are returned in the same order as
     they appear in [t]. *)
-val find_consecutive_duplicate
-  :  'a t
-  -> equal:(('a -> 'a -> bool)[@local])
-  -> ('a * 'a) option
+val find_consecutive_duplicate : 'a t -> equal:('a -> 'a -> bool) -> ('a * 'a) option
 
 (** [reduce f [a1; ...; an]] is [Some (f (... (f (f a1 a2) a3) ...) an)].  Returns [None]
     on the empty array. *)
-val reduce : 'a t -> f:(('a -> 'a -> 'a)[@local]) -> 'a option
+val reduce : 'a t -> f:('a -> 'a -> 'a) -> 'a option
 
-val reduce_exn : 'a t -> f:(('a -> 'a -> 'a)[@local]) -> 'a
+val reduce_exn : 'a t -> f:('a -> 'a -> 'a) -> 'a
 
 (** [permute ?random_state ?pos ?len t] randomly permutes [t] in place.
 
@@ -277,11 +259,11 @@ val unzip : ('a * 'b) t -> 'a t * 'b t
 
 (** [sorted_copy ar compare] returns a shallow copy of [ar] that is sorted. Similar to
     List.sort *)
-val sorted_copy : 'a t -> compare:(('a -> 'a -> int)[@local]) -> 'a t
+val sorted_copy : 'a t -> compare:('a -> 'a -> int) -> 'a t
 
 val last : 'a t -> 'a
 val equal : ('a -> 'a -> bool) -> 'a t -> 'a t -> bool
-
+val equal__local : ('a -> 'a -> bool) -> 'a t -> 'a t -> bool
 
 (** The input array is copied internally so that future modifications of it do not change
     the sequence. *)
@@ -299,12 +281,7 @@ val to_sequence_mutable : 'a t -> 'a Sequence.t
 module Private : sig
   module Sort : sig
     module type Sort = sig
-      val sort
-        :  'a t
-        -> compare:(('a -> 'a -> int)[@local])
-        -> left:int
-        -> right:int
-        -> unit
+      val sort : 'a t -> compare:('a -> 'a -> int) -> left:int -> right:int -> unit
     end
 
     module Insertion_sort : Sort
@@ -315,7 +292,7 @@ module Private : sig
 
       val five_element_sort
         :  'a t
-        -> compare:(('a -> 'a -> int)[@local])
+        -> compare:('a -> 'a -> int)
         -> int
         -> int
         -> int
@@ -326,17 +303,12 @@ module Private : sig
   end
 
   module Sorter (S : sig
-      type 'a t
+    type 'a t
 
-      val get : 'a t -> int -> 'a
-      val set : 'a t -> int -> 'a -> unit
-      val length : 'a t -> int
-    end) : sig
-    val sort
-      :  ?pos:int
-      -> ?len:int
-      -> 'a S.t
-      -> compare:(('a -> 'a -> int)[@local])
-      -> unit
+    val get : 'a t -> int -> 'a
+    val set : 'a t -> int -> 'a -> unit
+    val length : 'a t -> int
+  end) : sig
+    val sort : ?pos:int -> ?len:int -> 'a S.t -> compare:('a -> 'a -> int) -> unit
   end
 end
